# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2020 Óscar García Amor <ogarcia@connectical.com>
#
# Distributed under terms of the GNU GPLv3 license.

NAME = 'lpacli'
VERSION = '0.1.1'
AUTHOR_NAME = 'Óscar García Amor'
AUTHOR_EMAIL = 'ogarcia@connectical.com'
DESCRIPTION = 'CLI helper to get LessPass paswords configuration directly from a LessPass server.'
KEYWORDS = 'lesspass api client passwords'
URL = 'https://github.com/ogarcia/lpacli'
LICENSE = 'GPLv3'
